@@ -1,6 +1,6 @@
 from .amcache.amcache import AmCachePlugin
 from .bcd.boot_entry_list import BootEntryListPlugin
-from .ntuser.installed_programs_ntuser import InstalledSoftwareNTUserPlugin
+from .ntuser.installed_programs_ntuser import InstalledProgramsNTUserPlugin
 from .ntuser.network_drives import NetworkDrivesPlugin
 from .ntuser.persistence import NTUserPersistencePlugin
 from .ntuser.shellbags_ntuser import ShellBagNtuserPlugin
@@ -15,7 +15,7 @@ from .sam.local_sid import LocalSidPlugin
 from .security.domain_sid import DomainSidPlugin
 from .software.classes_installer import SoftwareClassesInstallerPlugin
 from .software.image_file_execution_options import ImageFileExecutionOptions
-from .software.installed_programs import InstalledSoftwarePlugin
+from .software.installed_programs import InstalledProgramsSoftwarePlugin
 from .software.last_logon import LastLogonPlugin
 from .software.persistence import SoftwarePersistencePlugin
 from .software.printdemon import PrintDemonPlugin
@@ -34,4 +34,6 @@ from .system.shimcache import ShimCachePlugin
 from .system.timezone_data import TimezoneDataPlugin
 from .system.usbstor import USBSTORPlugin
 from .system.wdigest import WDIGESTPlugin
-from .usrclass.classes_installer import ClassesInstallerPlugin
+from .usrclass.shellbags_usrclass import ShellBagUsrclassPlugin
+from .ntuser.classes_installer import NtuserClassesInstallerPlugin
+from .system.network_data import NetworkDataPlugin
