@@ -1,4 +1,4 @@
-import logbook
+import logging
 
 from inflection import underscore
 
@@ -7,7 +7,7 @@ from regipy.hive_types import AMCACHE_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 from regipy.utils import convert_wintime
 
-logger = logbook.Logger(__name__)
+logger = logging.getLogger(__name__)
 
 AMCACHE_FIELD_NUMERIC_MAPPINGS = {
     '0': 'product_name',
@@ -87,12 +87,12 @@ class AmCachePlugin(Plugin):
         self.entries.append(entry)
 
     def run(self):
-        logger.info('Started AmCache Plugin...')
+        logger.debug('Started AmCache Plugin...')
 
         try:
             amcache_file_subkey = self.registry_hive.get_key(r'\Root\File')
         except RegistryKeyNotFoundException:
-            logger.info(r'Could not find \Root\File subkey')
+            logger.error(r'Could not find \Root\File subkey')
             amcache_file_subkey = None
 
         try:
