@@ -3,18 +3,18 @@ from regipy.exceptions import RegistryKeyNotFoundException
 from regipy.hive_types import NTUSER_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 from regipy.utils import convert_wintime
+from regipy.constants import KNOWN_GUIDS
 import re
 
 logger = logging.getLogger(__name__)
 
 NTUSER_SHELLBAG = '\\Software\\Microsoft\\Windows\\Shell\\BagMRU'
-USRCLASS_SHELLBAG = '\\Local Settings\\Software\\Microsoft\\Windows\\Shell\\BagMRU'
 CODEPAGE = 'cp1252'
 
 
 class ShellBagNtuserPlugin(Plugin):
-    NAME = 'shellbag_plugin'
-    DESCRIPTION = 'Parse Shellbag items'
+    NAME = 'ntuser_shellbag_plugin'
+    DESCRIPTION = 'Parse NTUSER Shellbag items'
     COMPATIBLE_HIVE = NTUSER_HIVE_TYPE
 
     @staticmethod
@@ -48,13 +48,16 @@ class ShellBagNtuserPlugin(Plugin):
         elif isinstance(shell_item, pyfwsi.network_location):
             item_type = "Network Location"
 
+        elif isinstance(shell_item, pyfwsi.root_folder):
+            item_type = "Root Folder"
+
         else:
             item_type = 'unknown'
 
         return item_type
 
     @staticmethod
-    def _parse_shell_item_path_segment(shell_item):
+    def _parse_shell_item_path_segment(self, shell_item):
         """Parses a shell item path segment.
         Args:
           shell_item (pyfwsi.item): shell item.
@@ -76,7 +79,10 @@ class ShellBagNtuserPlugin(Plugin):
             if shell_item.name:
                 path_segment = shell_item.name
             elif shell_item.identifier:
-                path_segment = '{{{0:s}}}'.format(shell_item.identifier)
+                if shell_item.identifier in KNOWN_GUIDS:
+                    path_segment = KNOWN_GUIDS[shell_item.identifier]
+                else:
+                    path_segment = '{{{0:s}}}'.format(shell_item.identifier)
 
         elif isinstance(shell_item, pyfwsi.file_entry):
             long_name = ''
@@ -93,6 +99,14 @@ class ShellBagNtuserPlugin(Plugin):
             if shell_item.location:
                 path_segment = shell_item.location
 
+        elif isinstance(shell_item, pyfwsi.root_folder):
+            if shell_item.shell_folder_identifier in KNOWN_GUIDS:
+                path_segment = KNOWN_GUIDS[shell_item.shell_folder_identifier]
+            elif hasattr(shell_item, 'identifier') and shell_item.identifier in KNOWN_GUIDS:
+                path_segment = KNOWN_GUIDS[shell_item.identifier]
+            else:
+                path_segment = '{{{0:s}}}'.format(shell_item.shell_folder_identifier)
+
         if path_segment is None:
             path_segment = '<UNKNOWN: 0x{0:02x}>'.format(shell_item.class_type)
 
@@ -126,13 +140,12 @@ class ShellBagNtuserPlugin(Plugin):
                 shell_items.copy_from_byte_stream(byte_stream, ascii_codepage=CODEPAGE)
                 for item in shell_items.items:
                     shell_type = self._get_shell_item_type(item)
-                    value = self._parse_shell_item_path_segment(item)
-                    if shell_type != 'unknown':
-                        if not path:
-                            path = value
-                            base_path += f'\\{value}' if base_path else value
-                        else:
-                            path += f'\\{value}'
+                    value = self._parse_shell_item_path_segment(self, item)
+                    if not path:
+                        path = value
+                        base_path = ''
+                    else:
+                        path += f'\\{value}'
 
                     creation_time = None
                     access_time = None
