@@ -16,7 +16,7 @@ class RoutesPlugin(Plugin):
     COMPATIBLE_HIVE = SYSTEM_HIVE_TYPE
 
     def run(self):
-        logger.info('Started Routes Plugin...')
+        logger.debug('Started Routes Plugin...')
 
         routes_path_list = self.registry_hive.get_control_sets(ROUTES_PATH)
         self.entries = get_subkey_values_from_list(self.registry_hive, routes_path_list, as_json=self.as_json)
