@@ -1,10 +1,10 @@
-import logbook
+import logging
 
 from regipy.hive_types import SYSTEM_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 from regipy.plugins.system.external.ShimCacheParser import get_shimcache_entries
 
-logger = logbook.Logger(__name__)
+logger = logging.getLogger(__name__)
 
 COMPUTER_NAME_PATH = r'Control\Session Manager'
 
@@ -15,7 +15,7 @@ class ShimCachePlugin(Plugin):
     COMPATIBLE_HIVE = SYSTEM_HIVE_TYPE
 
     def run(self):
-        logger.info('Started Shim Cache Plugin...')
+        logger.debug('Started Shim Cache Plugin...')
 
         for subkey_path in self.registry_hive.get_control_sets(COMPUTER_NAME_PATH):
             appcompat_cache = self.registry_hive.get_key(subkey_path).get_subkey('AppCompatCache')
