@@ -12,7 +12,7 @@ REGF_HEADER = Struct(
     'root_key_offset' / Int32ul,
     'hive_bins_data_size' / Int32ul,
     'clustering_factor' / Int32ul,
-    'file_name' / CString('utf-16-le'),
+    'file_name' / PaddedString(64,'utf-16-le'),
     'padding' * Bytes(396),
     'checksum' / Int32ul
 
@@ -142,7 +142,7 @@ VALUE_KEY = Struct(
     'data_size' / Int32ul,
     'data_offset' / Int32ul,
     'data_type' / VALUE_TYPE_ENUM,
-    'flags' / Int16ul,
+    'flags' / FlagsEnum(Int16ul, VALUE_COMP_NAME=0x0001),
     'padding' * Int16ul,
     'name' / Bytes(this.name_size)
 ).compile()
